<?php


function istk_portfolio_setup() {	
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'wp-block-styles' );
	add_theme_support( 'title-tag' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'custom-logo' );
	add_theme_support( 'custom-header',
		array(
			'width'	=>	1280,
			'height'	=>	450,
			'default-image'	=>	get_template_directory_uri() . '/assets/images/header-sample.jpg',
			'uploads'	=>	true,
		)
	);
	add_theme_support( 'custom-background',
		array(
			'default-color'	=>	'#ffffff',
		)
	);
	
	add_theme_support(
		'html5',
		array(
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
			'style',
			'script',
			'navigation-widgets',
		)
	);
	
	add_theme_support( 'responsive-embeds' );
	
	register_nav_menus( array(
		'main_nav' => esc_html__( 'Main Navigation', 'istk-portfolio' ),//メインナビゲーション
		'footer_menu_1'  => esc_html__( 'Footer 1', 'istk-portfolio' ), //フッタ1
		'footer_menu_2'  => esc_html__( 'Footer 2', 'istk-portfolio' ), //フッタ2
	));
	
	if ( function_exists( 'add_image_size' ) ) { 
		add_image_size( 'istk_portfolio_head_img', 1280, 650 );
	}
	
	
	add_theme_support( 'editor-styles' );
	add_editor_style( 'editor.css' );
	
}
add_action( 'after_setup_theme', 'istk_portfolio_setup' );



if ( ! function_exists( 'wp_body_open' ) ) {
    function wp_body_open() {
        do_action( 'wp_body_open' );
    }
}
add_action( 'wp_footer', 'istk_portfolio_credit' );


function istk_portfolio_scripts() {
    wp_enqueue_style( 'dashicons' );
    wp_enqueue_style( 'istk_portfolio', get_stylesheet_uri(), array(), wp_get_theme()->get( 'Version' ));
	
	
	wp_enqueue_script( 'istk_portfolio', get_stylesheet_directory_uri() . '/assets/js/theme-scripts.js', array(), wp_get_theme()->get( 'Version' ), true);
	
	
	if ( is_front_page() ) {
		//フロントページのカルーセル
		if ( get_theme_mod( 'istk_portfolio_slider_on_off' ) === 'on' ) {
			wp_enqueue_style( 'swiper', get_stylesheet_directory_uri() . '/assets/css/swiper-bundle.min.css', array(), '6.5.3');
			wp_enqueue_script( 'swiper', get_stylesheet_directory_uri() . '/assets/js/swiper-bundle.min.js', array(), '6.5.3', true);
			wp_enqueue_script( 'istk_carousel', get_stylesheet_directory_uri() . '/assets/js/carousel.js', array( 'swiper' ), wp_get_theme()->get( 'Version' ), true);
		}
	}
	
	if ( is_singular() ) {
		wp_enqueue_script( "comment-reply" ); 
	}
	
}
add_action( 'wp_enqueue_scripts', 'istk_portfolio_scripts' );


function istk_portfolio_sidebar_registration() {
	
	register_sidebar( array(
		'name'	=>	esc_html__( 'Blog Sidebar', 'istk-portfolio' ),
		'id'	=>	'sidebar-1',
		'description'	=>	'',
	));
	
	register_sidebar( array(
		'name'	=>	esc_html__( 'Footer1', 'istk-portfolio' ),
		'id'	=>	'sidebar-2',
		'description'	=>	'',
	));
	
	register_sidebar( array(
		'name'	=>	esc_html__( 'Footer2', 'istk-portfolio' ),
		'id'	=>	'sidebar-3',
		'description'	=>	'',
	));
}
add_action( 'widgets_init', 'istk_portfolio_sidebar_registration' );


function istk_portfolio_content_width() {
	
	if ( isset( $GLOBALS[ 'content_width' ] ) ) {
		$content_width = $GLOBALS[ 'content_width' ];
	}
	
	$content_width = 960;
	
	if ( function_exists( 'istk_portfolio_sidebar_condition' ) ) {
		if ( istk_portfolio_sidebar_condition() ) {
			$content_width = 730;
		} else {
			$content_width = 960;
		}
	}
	
	$GLOBALS[ 'content_width' ] = apply_filters( 'istk_portfolio_content_width', $content_width );
}
add_action( 'template_redirect', 'istk_portfolio_content_width', 0 );




function istk_portfolio_add_body_class( $classes ) {
	if( function_exists( 'istk_portfolio_sidebar_condition_define' ) ) {
		if ( ISTK_PORTFOLIO__DISPLAY_SIDEBAR ) {
			$classes[] = 'sidebar-exists';
		} else {
			$classes[] = 'sidebar-none';
		}
	}
	
	if ( is_sticky() && is_single() ) {
		$classes[] = 'sticky';
	}
	
	
	if ( is_home() && ! is_front_page() ) {
		$classes[] = 'blog-home';
	}
	
	return $classes;
}
add_filter( 'body_class', 'istk_portfolio_add_body_class' );




require get_template_directory() . '/inc/customizer.php';
require get_template_directory() . '/inc/template-functions.php';
require get_template_directory() . '/inc/header_functions.php';
require get_template_directory() . '/inc/action-buttons.php';
require get_template_directory() . '/inc/customized-color.php';

//おすすめプラグイン
require get_template_directory() . '/inc/plugin-activation/setting.php';

